# Francine - Daily todo list

Francine is a command-line tool designed to help you keep track of your daily tasks,
always focusing on the first one inserted.

## Usage

![](https://media.giphy.com/media/vFKqnCdLPNOKc/giphy.gif)

## Installing

```bash
pip install francine
```
